@@ -1,26 +1,18 @@
 package Kevin::Command::kevin::worker;
-$Kevin::Command::kevin::worker::VERSION = '0.5.1'; # TRIAL
+$Kevin::Command::kevin::worker::VERSION = '0.5.2'; # TRIAL
 # ABSTRACT: Alternative Minion worker command
 use Mojo::Base 'Mojolicious::Command';
 
+use Minion::Worker;
 use Mojo::Util 'getopt';
 
 has description => 'Start alternative Minion worker';
 has usage => sub { shift->extract_usage };
 
-use constant TRACE => $ENV{KEVIN_WORKER_TRACE} || 0;
-
-sub _worker_class {
-  my $minion = shift;
-  my $class
-    = $minion->can('worker_class') ? $minion->worker_class : 'Minion::Worker';
-  return $class if $class->DOES('Minion::Worker::Role::Kevin');
-  return $class->with_roles('Minion::Worker::Role::Kevin');
-}
-
 sub _worker {
   my $minion = shift;
-  my $worker = _worker_class($minion)->new(minion => $minion, @_);
+  return $minion->kevin_worker(@_) if $minion->can('kevin_worker');
+  my $worker = Minion::Worker->with_roles('+Kevin')->new(minion => $minion, @_);
   $minion->emit(worker => $worker);
   return $worker;
 }
@@ -201,7 +193,7 @@ Kevin::Command::kevin::worker - Alternative Minion worker command
 
 =head1 VERSION
 
-version 0.5.1
+version 0.5.2
 
 =head1 SYNOPSIS
 
