@@ -1,20 +1,17 @@
 
 package Minion::Worker::Role::Kevin;
-$Minion::Worker::Role::Kevin::VERSION = '0.5.1'; # TRIAL
+$Minion::Worker::Role::Kevin::VERSION = '0.5.2'; # TRIAL
 # ABSTRACT: Alternative Minion worker
-use Role::Tiny;
+use Mojo::Base -role;
 
-use Mojo::Base;
 use Mojo::Log;
 use Mojo::Util 'steady_time';
 
 use constant TRACE => $ENV{KEVIN_WORKER_TRACE} || 0;
 
-# has 'defaults';
-Mojo::Base::attr(__PACKAGE__, 'defaults');
+has 'defaults';
 
-# has 'log' => sub { Mojo::Log->new };
-Mojo::Base::attr(__PACKAGE__, 'log', sub { Mojo::Log->new });
+has 'log' => sub { Mojo::Log->new };
 
 sub _defaults {
   return {
@@ -150,7 +147,7 @@ Minion::Worker::Role::Kevin - Alternative Minion worker
 
 =head1 VERSION
 
-version 0.5.1
+version 0.5.2
 
 =head1 AUTHOR
 
